<?php
/*
Plugin Name: Mount Olive Devotion
Plugin URI: http://rinaldo.net/projects/devotion-plugin
Description: Insert weekly devotion using shortcode
Version: 1.0.1
Date: 23 May 2018
Author: Bery Rinaldo <bery@rinaldo.net>
Author URI: http://rinaldo.net/
*/

/*
	Copyright 2018 Bery Rinaldo, Brian Knitter

	This program is free software; you can redistribute it and/or modify
	it under the terms of the GNU General Public License, version 2, as 
	published by the Free Software Foundation. A copy of the license is at
	http://www.gnu.org/licenses/gpl-2.0.html

	This program is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
	GNU General Public License for more details.
*/

/*
Note: This plugin requires WordPress version 4.3.1 or higher.

Information about the Mount Olive Devotion plugin along with
instructions and examples can be found here:

http://rinaldo.net/projects/devotion-plugin

Shortcode formats:

[mount_olive_devotion kind="preview"]
[mount_olive_devotion kind="full"]

Limitation:

Only one shortcode can be used per page.

Requirement:

The URL /devotion is a page with the full shortcode on it.
*/

#define( 'WP_DEBUG', true );

if( ! function_exists('bjrsu_mount_olive_devotion') )
{

	function bjrsu_mount_olive_devotion($content)
	{
		$bjrsu_content = $content;
		preg_match_all('!\[mount_olive_devotion[^\]].*kind=\"(.*?)\"\]!is',$bjrsu_content,$bjrsu_matches);
		$bjrsu_nummatches = count($bjrsu_matches[0]);
		for( $bjrsu_i=0; $bjrsu_i<$bjrsu_nummatches; $bjrsu_i++ )
		{
			$bjrsu_replacement = bjrsu_mount_olive_devotion_file_to_html($bjrsu_matches[1][$bjrsu_i]);
			$bjrsu_content = preg_replace('/'.preg_quote($bjrsu_matches[0][$bjrsu_i],'/').'/',$bjrsu_replacement,$bjrsu_content,1);
		}
		return $bjrsu_content;
	}
	add_filter( 'the_content', 'bjrsu_mount_olive_devotion', 9 );

	function bjrsu_week_between_two_dates($date1, $date2)
	{
		$first = strtotime($date1);
		$second = strtotime($date2);
#print "<p>DEBUG: date1 $date1 date2 $date2 f $first s $second<p>\n";
		if($first > $second) return bjrsu_week_between_two_dates($date2, $date1);
		$days = ($second - $first) / (24*60*60);
#print "<p>DEBUG: days $days<p>\n";
		$weeks = floor($days/7);
#print "<p>DEBUG: weeks $weeks<p>\n";
		return $weeks;
	}

	function bjrsu_mount_olive_devotion_file_to_html($kind)
	{
		#remove_filter( 'the_content', 'wpautop' );    # Needed to prevent extra <p> in Javascript and HTML below
		#remove_filter( 'the_content', 'wptexturize'); # And to stop && from getting messed up sometimes

		$html_text = "";
		$dpath = dirname(__FILE__);
		$doc_root = $_SERVER["DOCUMENT_ROOT"];
		$ppath = preg_replace("|$doc_root|","",$dpath);
		#$html_text .= "\n\n<p>doc_root $doc_root dpath $dpath ppath $ppath<p>\n";
		$check = "NA";

		if ( file_exists("$dpath/started.txt") )
		{
		#$html_text .= "\n<p>fount existing started.txt<p>\n";
			$lhandle = @fopen("$dpath/started.txt","r");
			if ($lhandle)
			{
				$check = fgets($lhandle);
		#$html_text .= "\n<p>check $check <p>\n";
				fclose($lhandle);
			}
		}
		else
		{
			$lhandle = @fopen("$dpath/started.txt","w");
			if ($lhandle)
			{
				$check = strftime("%Y-%m-%d");
				fwrite($lhandle,"$check\n");
				fclose($lhandle);
			}
		}
		$now = strftime("%Y-%m-%d");
		#$html_text .= "\n\n<p>check $check now $now <p>\n";

		$wkdif = bjrsu_week_between_two_dates($check, $now);

		#$html_text .= "\n\n<p>dpath $dpath check $check now $now wkdif $wkdif<p>\n";

		$darr = Array();
		$dcount = 0;
		foreach (glob("$dpath/data/devotion_*.txt") as $filename)
		{
			#$html_text .= "\n\n<p>dcount $dcount filename $filename<p>\n";
			$darr[$dcount] = $filename;
			$dcount++;
		}

		$mindex = $wkdif % $dcount;
		#$html_text .= "\n\n<p>mindex $mindex filename $darr[$mindex]<p>\n";
		#return $html_text;

		$title = "";
		$author = "";
		$scripture = "";
		$opener = "";
		$text = "";

		$fp = @fopen($darr[$mindex], "r");
		if ($fp)
		{
			$in_opener = 0;
			$in_text = 0;
			while (!feof ($fp))
			{
				$buffer = fgets($fp);
				$bl = strlen($buffer);
				if (substr($buffer,0,5) == "TITLE")
				{
					$title = substr($buffer,6,$bl-7);
				}
				if (substr($buffer,0,9) == "SCRIPTURE")
				{
					$scripture = substr($buffer,10,$bl-11);
				}
				if (substr($buffer,0,6) == "AUTHOR")
				{
					$author = substr($buffer,7,$bl-8);
				}
				if (substr($buffer,0,4) == "TEXT")
				{
					$in_opener = 0;
				}
				if ($in_opener)
				{
					$opener .= $buffer;
				}
				if ($in_text)
				{
					if ($bl == 1)
					{
						$text .= "<p>";
					}
					$text .= $buffer;
				}
				if (substr($buffer,0,6) == "OPENER")
				{
					$in_opener = 1;
				}
				if (substr($buffer,0,4) == "TEXT")
				{
					$in_text = 1;
				}
			}
			fclose($fp);
		}
		else
		{
			$html_text .= "<h1>Not Found</h1>\n";
			$html_text .= "Sorry, this devotion ($devo) was not found.\n";
		}

		#$html_text .= "<p>kind $kind<p>";

		if ($kind == "full")
		{
			$html_text .= "<h1>$title</h1>\n";
			if ($scripture != "")
			{
				$slink = str_replace(" ","+",$scripture);
				$slink = str_replace(":","%3A",$slink);
				$url="http://www.biblegateway.com/cgi-bin/bible?passage=$slink&version=NIV&language=english";
				$html_text .= "<a target=\"_blank\" href=\"$url\">$scripture</a><br>\n";
			}

			$html_text .= "by $author\n<p>\n";
			$html_text .= $text;

		}
		else
		{
			$html_text .= "<table cellpadding=\"3\" cellspacing=\"3\" border=\"0\">\n";
			$html_text .= "<tr><td align=\"justify\">\n";
			$html_text .= "<h2><a href=\"/devotion/\">$title</a></h2>\n";
			if ($scripture != "")
			{
				$slink = str_replace(" ","+",$scripture);
				$slink = str_replace(":","%3A",$slink);
				$url="http://www.biblegateway.com/cgi-bin/bible?passage=$slink&version=NIV&language=english";
				$html_text .= "<a target=\"_blank\" href=\"$url\">$scripture</a><br>\n";
			}

			$html_text .= "by $author<p>";
			$html_text .= rtrim($opener);

			$html_text .= "<a class=\"more-link\" href=\"/devotion/\"><span class=\"more-button\">Continue reading &gt;</span></a></td></tr></table>";
		}
		return $html_text;
	}

} # if( ! function_exists('bjrsu_mount_olive_devotion') )

?>
